/*
 * Operations and their invocation.
 *
 * Copyright (C) 2022, 2024 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

/* Invocation support. */

enum op_results
{
    OP_SUCCESS = 0,
    OP_FAILED = 1,
    OP_UNKNOWN = 2,
};

int handle_op_result(const char *operation, enum op_results op_result);
enum op_results run_operation(const char *operation, int argc, char *argv[],
                              int *exitcode);

/* Operations exposed by the program. */

typedef int (*op_sig)(int, char *[]);

struct operation
{
    const char *name;
    op_sig fn;
};

int copy_in(int argc, char *argv[]);
int copy_out(int argc, char *argv[]);
int file_to_program(int argc, char *argv[]);
int list_objects(int argc, char *argv[]);
int make_dirs(int argc, char *argv[]);
int pipe_to_program(int argc, char *argv[]);
int remove_dirs(int argc, char *argv[]);
int remove_non_dirs(int argc, char *argv[]);
int run_program(int argc, char *argv[]);
int spawn_program(int argc, char *argv[]);
int run_script(int argc, char *argv[]);
int show_programs(int argc, char *argv[]);
int stat_objects(int argc, char *argv[]);
int wait_program(int argc, char *argv[]);

/* vim: tabstop=4 expandtab shiftwidth=4
*/
